# CPrint
a test package to print colorful text in the console

## Colors
- header
- blue
- cyan
- true
- warning
- false
- endc
- bold
- underline

🛈 *colors must be all capital*

## Installation

```
pip install CPrint
```

## Function call

```
from CPrint import *

cprint('text', 'string', 12, color='BLUE')
```
